From 81f6b301eb0ba7dacd314c4bade04a23b437ed8e Mon Sep 17 00:00:00 2001
From: Han Kai <hankai2@huawei.com>
Date: Tue, 17 Nov 2020 16:04:50 +0800
Subject: [PATCH] cpu_custom: fix some bugs

1.kunpeng-916 not support the features of kunpeng-920
2.add -w for grep

Signed-off-by: Kai Han <hankai2@huawei.com>
Signed-off-by: Chen Qun <kuhn.chenqun@huawei.com>
---
 qemu/tests/cpu_custom.py | 33 ++++++++++++++++++---------------
 1 file changed, 18 insertions(+), 15 deletions(-)

diff --git a/qemu/tests/cpu_custom.py b/qemu/tests/cpu_custom.py
index 7724590a..22a5813a 100644
--- a/qemu/tests/cpu_custom.py
+++ b/qemu/tests/cpu_custom.py
@@ -17,25 +17,13 @@ def run(test, params, env):
     :param params: Dictionary with the test parameters
     :param env: Dictionary with test environment.
     """
-    mode_name = params.get("model_name")
-    feature_name = params.get("feature_name")
-    feature_policy = params.get("flag")
-    cpu_model_flags = "," + feature_name + "=" + feature_policy
-    vm0 = env.get_vm(params["main_vm"])
-
-    params["cpu_model"] = mode_name
-    params["cpu_model_flags"] = cpu_model_flags
-    params["start_vm"] = "yes"
-    env_process.preprocess_vm(test, params, env, params["main_vm"])
-    session = vm0.wait_for_login()
-
     def check_cpu_feature(feature, policy):
         """
         check cpu feature in vm according to the policy
         :param feature: cpu feature name
         :param policy: enable or disable cpu feature
         """
-        status, result = session.cmd_status_output("lscpu | grep Flags | grep %s" % feature)
+        status, result = session.cmd_status_output("lscpu | grep Flags | grep -w %s" % feature)
         if policy == "on":
             if status != 0:
                 test.fail("no feature found %s, stdout is %s" % (feature, result))
@@ -55,5 +43,20 @@ def run(test, params, env):
         if not result:
             test.fail("cmdline has no %s" % keyword)
 
-    check_cpu_feature(feature_name, feature_policy)
-    check_qemu_cmdline(feature_name, feature_policy)
+    mode_name = params.get("model_name")
+    feature_name = params.get("feature_name")
+    feature_policy = params.get("flag")
+    cpu_model_flags = "," + feature_name + "=" + feature_policy
+    cmd = "lscpu | grep 'Model name' | awk '{print $3}'"
+    machine_arch = process.run(cmd, shell=True, ignore_status=True).stdout_text.replace('\n', '')
+    if machine_arch != "Cortex-A72" or mode_name == "Cortex-A72":
+        vm0 = env.get_vm(params["main_vm"])
+
+        params["cpu_model"] = mode_name
+        params["cpu_model_flags"] = cpu_model_flags
+        params["start_vm"] = "yes"
+        env_process.preprocess_vm(test, params, env, params["main_vm"])
+        session = vm0.wait_for_login()
+
+        check_cpu_feature(feature_name, feature_policy)
+        check_qemu_cmdline(feature_name, feature_policy)
-- 
2.23.0

